Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: components/autofill/core/browser/autofill_metrics.h

Issue 1392623002: [Autofill] Add metric for profile action on form submitted (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | components/autofill/core/browser/autofill_metrics.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/autofill/core/browser/autofill_metrics.h
diff --git a/components/autofill/core/browser/autofill_metrics.h b/components/autofill/core/browser/autofill_metrics.h
index 66301fbc13372b558d98e78b7c5f599bf863a9ff..cbdbcabf4e4bfa57fc1dc71307e1111f48e3f07d 100644
--- a/components/autofill/core/browser/autofill_metrics.h
+++ b/components/autofill/core/browser/autofill_metrics.h
@@ -22,6 +22,13 @@ namespace autofill {
class AutofillMetrics {
public:
+ enum AutofillProfileAction {
+ EXISTING_PROFILE_USED,
+ EXISTING_PROFILE_UPDATED,
+ NEW_PROFILE_CREATED,
+ AUTOFILL_PROFILE_ACTION_ENUM_SIZE,
+ };
+
enum DeveloperEngagementMetric {
// Parsed a form that is potentially autofillable.
FILLABLE_FORM_PARSED = 0,
@@ -579,9 +586,9 @@ class AutofillMetrics {
// This should be called each time a server response is parsed for a form.
static void LogServerResponseHasDataForForm(bool has_data);
- // This should be called at each form submission to indicate whether a new
- // profile was created.
- static void LogAutomaticProfileCreation(bool created);
+ // This should be called at each form submission to indicate what profile
+ // action happened.
+ static void LogProfileActionOnFormSubmitted(AutofillProfileAction action);
// Utility to autofill form events in the relevant histograms depending on
// the presence of server and/or local data.
« no previous file with comments | « no previous file | components/autofill/core/browser/autofill_metrics.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698